Fix broken links in doc comments after Mapping -> Apply change.

Tue, 06 Dec 2022 08:32:57 +0200

author
Tuomo Valkonen <tuomov@iki.fi>
date
Tue, 06 Dec 2022 08:32:57 +0200
changeset 15
e03ce15643da
parent 14
f5b9f4bf25a7
child 16
703482dffd87

Fix broken links in doc comments after Mapping -> Apply change.

src/bisection_tree/support.rs file | annotate | diff | comparison | revisions
--- a/src/bisection_tree/support.rs	Tue Dec 06 08:29:13 2022 +0200
+++ b/src/bisection_tree/support.rs	Tue Dec 06 08:32:57 2022 +0200
@@ -1,6 +1,6 @@
 
 /*!
-Traits for representing the support of a [`Mapping`], and analysing the mapping on a [`Cube`].
+Traits for representing the support of a [`Apply`], and analysing the mapping on a [`Cube`].
 */
 use serde::Serialize;
 use std::ops::{MulAssign,DivAssign,Neg};
@@ -27,9 +27,9 @@
 }
 
 
 /// A trait for working with the supports of [`Mapping`]s.
 ///
 /// Mapping is not a super-trait to allow more general use.
 pub trait Support<F : Num, const N : usize> : Sized + Sync + Send + 'static {
     /// Return a cube containing the support of the function represented by `self`.
     ///
@@ -70,7 +70,7 @@
     }
 }
 
 /// Trait for globally analysing a property `A` of a [`Mapping`].
 ///
 /// Typically `A` is an [`Aggregator`][super::aggregator::Aggregator] such as
 /// [`Bounds`][super::aggregator::Bounds].
@@ -91,7 +91,7 @@
 //     }
 // }
 
 /// Trait for locally analysing a property `A` of a [`Mapping`] (implementing [`Support`])
 /// within a [`Cube`].
 ///
 /// Typically `A` is an [`Aggregator`][super::aggregator::Aggregator] such as
@@ -105,10 +105,10 @@
     fn local_analysis(&self, cube : &Cube<F, N>) -> A;
 }
 
 /// Trait for determining the upper and lower bounds of an float-valued [`Mapping`].
 ///
 /// This is a blanket-implemented alias for [`GlobalAnalysis`]`<F, Bounds<F>>`
 /// [`Mapping`] is not a supertrait to allow flexibility in the implementation of either
 /// reference or non-reference arguments.
 pub trait Bounded<F : Float> : GlobalAnalysis<F, Bounds<F>> {
     /// Return lower and upper bounds for the values of of `self`.
@@ -120,7 +120,7 @@
 
 impl<F : Float, T : GlobalAnalysis<F, Bounds<F>>> Bounded<F> for T { }
 
 /// Shift of [`Support`] and [`Mapping`]; output of [`Support::shift`].
 #[derive(Copy,Clone,Debug,Serialize)] // Serialize! but not implemented by Loc.
 pub struct Shift<T, F, const N : usize> {
     shift : Loc<F, N>,
@@ -200,13 +200,13 @@
 
 impl_shift_norm!(L1 L2 Linfinity);
 
-/// Weighting of a [`Support`] and [`Mapping`] by scalar multiplication;
+/// Weighting of a [`Support`] and [`Apply`] by scalar multiplication;
 /// output of [`Support::weigh`].
 #[derive(Copy,Clone,Debug,Serialize)]
 pub struct Weighted<T, C : Constant> {
     /// The weight
     pub weight : C,
     /// The base [`Support`] or [`Mapping`] being weighted.
     pub base_fn : T,
 }
 
@@ -331,12 +331,12 @@
 impl_weighted_norm!(L1 L2 Linfinity);
 
 
 /// Normalisation of [`Support`] and [`Mapping`] to L¹ norm 1.
 ///
 /// Currently only scalar-valued functions are supported.
 #[derive(Copy, Clone, Debug, Serialize, PartialEq)]
 pub struct Normalised<T>(
     /// The base [`Support`] or [`Mapping`].
     pub T
 );
 
@@ -449,7 +449,7 @@
 : MulAssign<F> + DivAssign<F> + Neg<Output=Self> + Clone + Sync + Send + 'static {
     /// The identification type
     type Id : 'static + Copy;
     /// The type of the [`Support`] (often also a [`Mapping`]).
     type SupportType : 'static + Support<F, N>;
     /// An iterator over all the [`Support`]s of the generator.
     type AllDataIter<'a> : Iterator<Item=(Self::Id, Self::SupportType)> where Self : 'a;
@@ -27,9 +27,9 @@
 
 
-/// A trait for working with the supports of [`Mapping`]s.
+/// A trait for working with the supports of [`Apply`]s.
 ///
@@ -27,9 +27,9 @@
 ///
-/// Mapping is not a super-trait to allow more general use.
+/// Apply is not a super-trait to allow more general use.
 pub trait Support<F : Num, const N : usize> : Sized + Sync + Send + 'static {
     /// Return a cube containing the support of the function represented by `self`.
@@ -70,7 +70,7 @@
 }
 
-/// Trait for globally analysing a property `A` of a [`Mapping`].
+/// Trait for globally analysing a property `A` of a [`Apply`].
 ///
 /// Typically `A` is an [`Aggregator`][super::aggregator::Aggregator] such as
@@ -91,7 +91,7 @@
 // }
 
-/// Trait for locally analysing a property `A` of a [`Mapping`] (implementing [`Support`])
+/// Trait for locally analysing a property `A` of a [`Apply`] (implementing [`Support`])
 /// within a [`Cube`].
 ///
@@ -105,10 +105,10 @@
 }
 
-/// Trait for determining the upper and lower bounds of an float-valued [`Mapping`].
+/// Trait for determining the upper and lower bounds of an float-valued [`Apply`].
 ///
 /// This is a blanket-implemented alias for [`GlobalAnalysis`]`<F, Bounds<F>>`
@@ -105,10 +105,10 @@
 ///
 /// This is a blanket-implemented alias for [`GlobalAnalysis`]`<F, Bounds<F>>`
-/// [`Mapping`] is not a supertrait to allow flexibility in the implementation of either
+/// [`Apply`] is not a supertrait to allow flexibility in the implementation of either
 /// reference or non-reference arguments.
 pub trait Bounded<F : Float> : GlobalAnalysis<F, Bounds<F>> {
@@ -120,7 +120,7 @@
 impl<F : Float, T : GlobalAnalysis<F, Bounds<F>>> Bounded<F> for T { }
 
-/// Shift of [`Support`] and [`Mapping`]; output of [`Support::shift`].
+/// Shift of [`Support`] and [`Apply`]; output of [`Support::shift`].
 #[derive(Copy,Clone,Debug,Serialize)] // Serialize! but not implemented by Loc.
 pub struct Shift<T, F, const N : usize> {
@@ -200,13 +200,13 @@
     /// The weight
     pub weight : C,
-    /// The base [`Support`] or [`Mapping`] being weighted.
+    /// The base [`Support`] or [`Apply`] being weighted.
     pub base_fn : T,
 }
@@ -331,12 +331,12 @@
 
 
-/// Normalisation of [`Support`] and [`Mapping`] to L¹ norm 1.
+/// Normalisation of [`Support`] and [`Apply`] to L¹ norm 1.
 ///
 /// Currently only scalar-valued functions are supported.
@@ -331,12 +331,12 @@
 #[derive(Copy, Clone, Debug, Serialize, PartialEq)]
 pub struct Normalised<T>(
-    /// The base [`Support`] or [`Mapping`].
+    /// The base [`Support`] or [`Apply`].
     pub T
 );
@@ -449,7 +449,7 @@
     /// The identification type
     type Id : 'static + Copy;
-    /// The type of the [`Support`] (often also a [`Mapping`]).
+    /// The type of the [`Support`] (often also a [`Apply`]).
     type SupportType : 'static + Support<F, N>;
     /// An iterator over all the [`Support`]s of the generator.

mercurial